@@ -397,7 +397,8 @@ class ConfigManager:
             "color_detection": None,  # Will be set later to avoid circular import
             "video_color_classification": None,  # Alias for color_detection
             "vehicle_monitoring" : None,
-            "fire_smoke_detection": None
+            "fire_smoke_detection": None,
+            "flare_analysis" : None
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -427,6 +428,14 @@ class ConfigManager:
             return FireSmokeConfig
         except ImportError:
             return None
+        
+    def flare_analysis_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.flare_analysis import FlareAnalysisConfig
+            return FlareAnalysisConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -547,6 +556,22 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "flare_analysis":
+            # Import here to avoid circular import
+            from ..usecases.flare_analysis import FlareAnalysisConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = FlareAnalysisConfig(
+                category=category or "normal",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "vehicle_monitoring":
             # Import here to avoid circular import
             from ..usecases.vehicle_monitoring import VehicleMonitoringConfig
@@ -738,6 +763,11 @@ class ConfigManager:
             from ..usecases.color_detection import ColorDetectionConfig
             default_config = ColorDetectionConfig()
             return default_config.to_dict()
+        elif usecase == "flare_analysis":
+            # Import here to avoid circular import
+            from ..usecases.flare_analysis import FlareAnalysisConfig
+            default_config = FlareAnalysisConfig()
+            return default_config.to_dict()
         elif usecase == "ppe_compliance_detection":
             # Import here to avoid circular import
             from ..usecases.ppe_compliance import PPEComplianceConfig
